@@ -1,6 +1,6 @@
 package MooX::BuildArgsHooks;
 
-$MooX::BuildArgsHooks::VERSION = '0.05';
+$MooX::BuildArgsHooks::VERSION = '0.06';
 
 =head1 NAME
 
@@ -80,7 +80,8 @@ use strictures 2;
 use namespace::clean;
 
 BEGIN {
-    package MooX::BuildArgsHooks::Test;
+    package # NO INDEX
+        MooX::BuildArgsHooks::Test;
     use Moo;
     around BUILDARGS => sub{
         my $orig = shift;
